@@ -46,6 +46,7 @@ PIXEL_DICT = {
     "gray32": np.uint32,
     "bgr24": np.uint8,
     "bgr48": np.uint16,
+    "invalid": np.uint8,
 }
 
 
@@ -67,6 +68,9 @@ class CziReader(Reader):
         Note: DimensionNames.SpatialY, DimensionNames.SpatialX, and
         DimensionNames.Samples, will always be added to the list if not present during
         dask array construction.
+    include_subblock_metadata: bool
+        Whether to append metadata from the subblocks to the rest of the embeded
+        metadata.
 
     Notes
     -----
@@ -88,6 +92,7 @@ class CziReader(Reader):
         image: types.PathLike,
         chunk_dims: Union[str, List[str]] = DEFAULT_CHUNK_DIMS,
         chunk_by_dims: Optional[Union[str, List[str]]] = None,
+        include_subblock_metadata: bool = False,
     ):
         # Expand details of provided image
         self._fs, self._path = io_utils.pathlike_to_fs(image, enforce_exists=True)
@@ -114,6 +119,8 @@ class CziReader(Reader):
 
         self.chunk_dims = chunk_dims
 
+        self._include_subblock_metadata = include_subblock_metadata
+
         # Delayed storage
         self._px_sizes: Optional[types.PhysicalPixelSizes] = None
         self._mapped_dims: Optional[str] = None
@@ -395,7 +402,7 @@ class CziReader(Reader):
             # Get pixel type and catch unsupported
             pixel_type = PIXEL_DICT.get(czi.pixel_type)
             if pixel_type is None:
-                raise TypeError(f"Pixel type: {pixel_type} is not supported.")
+                raise TypeError(f"Pixel type: {czi.pixel_type} is not supported.")
 
             # Add delayed array to lazy arrays at index
             lazy_arrays[np_index] = da.from_delayed(
@@ -545,15 +552,28 @@ class CziReader(Reader):
                 dims_shape=dims_shape,
             )
 
+            # Append subblock metadata to the other metadata if param is True
+            if self._include_subblock_metadata:
+                subblocks = czi.read_subblock_metadata(unified_xml=True)
+                meta.append(subblocks)
+
             # Store pixel sizes
             self._px_sizes = px_sizes
 
-            return xr.DataArray(
-                image_data,
-                dims=img_dims_list,
-                coords=coords,  # type: ignore
-                attrs={constants.METADATA_UNPROCESSED: meta},
-            )
+            # handle edge case where image has 0,0 YX dims:
+            if image_data.shape[-2:] == (0, 0):
+                return xr.DataArray(
+                    dims=coords.keys(),
+                    coords=coords,
+                    attrs={constants.METADATA_UNPROCESSED: meta},
+                )
+            else:
+                return xr.DataArray(
+                    image_data,
+                    dims=img_dims_list,
+                    coords=coords,  # type: ignore
+                    attrs={constants.METADATA_UNPROCESSED: meta},
+                )
 
     def _read_immediate(self) -> xr.DataArray:
         """
