@@ -1,23 +1,66 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import logging
-import warnings
 from collections import Counter
+from typing import Any
 
 from . import types
-from .constants import Dimensions
 from .exceptions import ConflictingArgumentsError
 
 ###############################################################################
 
-log = logging.getLogger(__name__)
 
-###############################################################################
+def transpose_to_dims(
+    data: types.ArrayLike,
+    given_dims: str,
+    return_dims: str,
+) -> types.ArrayLike:
+    """
+    This shuffles the data dimensions from given_dims to return_dims. Each dimension
+    must be present in given_dims must be used in return_dims
+
+    Parameters
+    ----------
+    data: types.ArrayLike
+        Either a dask array or numpy.ndarray of arbitrary shape but with the dimensions
+        specified in given_dims
+    given_dims: str
+        The dimension ordering of data, "CZYX", "VBTCXZY" etc
+    return_dims: str
+        The dimension ordering of the return data
+
+    Returns
+    -------
+    data: types.ArrayLike
+        The data with the specified dimension ordering.
+
+    Raises
+    ------
+    ConflictingArgumentsError
+        given_dims and return_dims are incompatible.
+    """
+    # Use a counter to track that the contents are composed of the same letters
+    # and that no letter is repeated
+    if (
+        Counter(given_dims) != Counter(return_dims)
+        or max(Counter(given_dims).values()) > 1
+    ):
+        raise ConflictingArgumentsError(
+            f"given_dims={given_dims} and return_dims={return_dims} are incompatible."
+        )
+
+    # Resort the data into return_dims order
+    match_map = {dim: given_dims.find(dim) for dim in given_dims}
+    transposer = []
+    for dim in return_dims:
+        transposer.append(match_map[dim])
+    data = data.transpose(transposer)
+
+    return data
 
 
 def reshape_data(
-    data: types.ArrayLike, given_dims: str, return_dims: str, **kwargs
+    data: types.ArrayLike, given_dims: str, return_dims: str, **kwargs: Any
 ) -> types.ArrayLike:
     """
     Reshape the data into return_dims, pad missing dimensions, and prune extra
@@ -52,8 +95,16 @@ def reshape_data(
     Returns
     -------
     data: types.ArrayLike
-        An array in return_dims order, if return_dims=DEFAULT_DIMS then the return
-        would have order "STCZYX"
+        The data with the specified dimension ordering.
+
+    Raises
+    ------
+    ConflictingArgumentsError
+        Missing dimension in return dims when using range, slice, or multi-index
+        dimension selection for the requested dimension.
+
+    IndexError
+        Requested dimension index not present in data.
 
     Examples
     --------
@@ -98,7 +149,7 @@ def reshape_data(
     ... example = reshape_data(data, "CYX", "BSTCZYX", C=slice(0, -1, 3))
     """
     # Check for parameter conflicts
-    for dim in Dimensions.DefaultOrderList:
+    for dim in given_dims:
         # return_dims='TCZYX' and fixed dimensions 'C=1'
         # Dimension is in kwargs
         # Dimension is an integer
@@ -119,7 +170,7 @@ def reshape_data(
             and dim not in return_dims
         ):
             raise ConflictingArgumentsError(
-                f"When selecting a multiple dimension indicies, the specified "
+                f"When selecting a multiple dimension indices, the specified "
                 f"dimension must be provided in return_dims. "
                 f"return_dims={return_dims}, dimension {dim} = {kwargs.get(dim)}"
             )
@@ -173,13 +224,6 @@ def reshape_data(
                 # Check that integer
                 check_selection_max = dim_spec
             else:
-                # Dimension wasn't included in kwargs, default to zero
-                warnings.warn(
-                    f"Data has dimension {dim} with depth {data.shape[dim_index]}, "
-                    f"assuming {dim}=0 is the desired value, "
-                    f"if not the case specify {dim}=x where "
-                    f"x is an integer, list, tuple, range, or slice."
-                )
                 dim_spec = 0
                 display_dim_spec = dim_spec
                 check_selection_max = 0
@@ -212,44 +256,3 @@ def reshape_data(
     return transpose_to_dims(
         data, given_dims=new_dims, return_dims=return_dims
     )  # don't pass kwargs or 2 copies
-
-
-def transpose_to_dims(
-    data: types.ArrayLike,
-    given_dims: str,
-    return_dims: str,
-) -> types.ArrayLike:
-    """
-    This shuffles the data dimensions from given_dims to return_dims. Each dimension
-    must be present in given_dims must be used in return_dims
-
-    data: types.ArrayLike
-        Either a dask array or numpy.ndarray of arbitrary shape but with the dimensions
-        specified in given_dims
-    given_dims: str
-        The dimension ordering of data, "CZYX", "VBTCXZY" etc
-    return_dims: str
-        The dimension ordering of the return data
-
-    Returns
-    -------
-    data: types.ArrayLike
-        An array in return_dims order, if return_dims=DEFAULT_DIMS then the return
-        would have order "STCZYX"
-    """
-    # Use a counter to track that the contents are composed of the same letters
-    # and that no letter is repeated
-    if (
-        Counter(given_dims) != Counter(return_dims)
-        or max(Counter(given_dims).values()) > 1
-    ):
-        raise ConflictingArgumentsError(
-            f"given_dims={given_dims} and return_dims={return_dims} are incompatible."
-        )
-    # Resort the data into return_dims order
-    match_map = {dim: given_dims.find(dim) for dim in given_dims}
-    transposer = []
-    for dim in return_dims:
-        transposer.append(match_map[dim])
-    data = data.transpose(transposer)
-    return data
